@@ -127,30 +127,30 @@ def handle_server(server,addr):
     mpv.command("set_property","osd-font-size","18")
 
 
-    @mpv.property_observer("paused-for-cache")
-    def observe_playback_time(name, value):
-        global restart
-        if value == True:
-            print("seek = true")
-            restart+=1
-            if restart == 1:
-                restart = 0
-                restart_url = mpv.command("get_property","path")
-                skip_time = mpv.command("get_property","playback-time")
-
-                send(client_socket, "toggle play")
-                mpv.play("https://www.youtube.com/watch?v=dQw4w9WgXcQ")
-               
-                mpv.play(restart_url)
-                #ready_when_seeked(mpv, value)
-                while True:
-                    seek_bool = mpv.command("get_property","seeking")
-                    if seek_bool == False:
-                        pause_video(mpv)
-                        break
-                
-                mpv.command("set_property","playback-time",skip_time)
-                #new_video(mpv, "https://www.youtube.com/watch?v=dQw4w9WgXcQ")
+#    @mpv.property_observer("paused-for-cache")
+#    def observe_playback_time(name, value):
+#        global restart
+#        if value == True:
+#            print("seek = true")
+#            restart+=1
+#            if restart == 4:
+#                restart = 0
+#                restart_url = mpv.command("get_property","path")
+#                skip_time = mpv.command("get_property","playback-time")
+#
+#                send(client_socket, "toggle play")
+#                mpv.play("https://www.youtube.com/watch?v=dQw4w9WgXcQ")
+#               
+#                mpv.play(restart_url)
+#                #ready_when_seeked(mpv, value)
+#                while True:
+#                    seek_bool = mpv.command("get_property","seeking")
+#                    if seek_bool == False:
+#                        pause_video(mpv)
+#                        break
+#                
+#                mpv.command("set_property","playback-time",skip_time)
+#                #new_video(mpv, "https://www.youtube.com/watch?v=dQw4w9WgXcQ")
                 
 
 
@@ -213,39 +213,40 @@ def handle_server(server,addr):
         send(client_socket, "frame-back-step")
         pause_video(mpv)
         mpv.command('frame-back-step')
-        print('nigga')
+
 
     @mpv.on_key_press(".")
     def frame_step():
         send(client_socket, "frame-step")
         #pause_video(mpv)
         mpv.command('frame-step')
-        print('nigga')
 
-    @mpv.on_key_press("b")
-    def add_speed():
-        print("")
-        send(client_socket, "add_speed")
-        mpv.command('add','speed',0.1)
-        print('sped up')
-
-    @mpv.on_key_press("n")
+    @mpv.on_key_press("-")
     def subtract_speed():
         print("n")
         send(client_socket, "subtract_speed")
         mpv.command('add','speed',-0.1)
+        speed = mpv.command('get_property','speed')      
+        mpv.command("show-text",f"Setting playback-speed to {speed}", "1500")
         print('slowed down')
 
+    @mpv.on_key_press("+")
+    def add_speed():
+        print("")
+        send(client_socket, "add_speed")
+        mpv.command('add','speed',0.1)
+        speed = mpv.command('get_property','speed')      
+        mpv.command("show-text",f"Setting playback-speed to {speed}", "1500")
+        print('sped up')
+
     @mpv.on_key_press("r")
     def resync():
         time_pos = mpv.command("get_property","time-pos")
         print(time_pos)
-
         send(client_socket, f"mpv skip {time_pos}")
+        send(client_socket, "resync")
         ready_when_seeked(mpv, time_pos)
 
-
-
     print(f"[CONNECTION ESTABLISHED] to {addr}")
     
     while connected:
@@ -263,10 +264,15 @@ def handle_server(server,addr):
                     mpv.command('frame-step')
 
                 if msg == 'add_speed':
-                    mpv.command('add','speed',0.1)          
-                    
+                    mpv.command('add','speed',0.1)
+                    speed = mpv.command('get_property','speed')      
+                    mpv.command("show-text",f"{user} sets playback-speed to {speed}", "1500")
+    
+
                 if msg == 'subtract_speed':
-                    mpv.command('add','speed',-0.1)  
+                    mpv.command('add','speed',-0.1)
+                    speed = mpv.command('get_property','speed')      
+                    mpv.command("show-text",f"{user} sets playback-speed to {speed}", "1500") 
 
                 if msg == "frame-back-step":
                     mpv.command('frame-back-step')
@@ -286,6 +292,9 @@ def handle_server(server,addr):
                 if msg == "number of clients":
                     number_of_clients = int(msg.split[" "][3])
                     print ("Number of Clients: %s"%number_of_clients)
+
+                if msg == "resync":
+                    mpv.command("show-text",f"{user} resyncs.", "1500") 
                     
                 if msg == "toggle play":
                     toggle_play(mpv)
